package com.flyer.foster.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.flyer.exception.BusinessException;
import com.flyer.foster.dto.AreaAddDTO;
import com.flyer.foster.dto.AreaQueryDTO;
import com.flyer.foster.dto.AreaRespDTO;
import com.flyer.foster.dto.AreaUpdateDTO;
import com.flyer.foster.entity.Area;
import com.flyer.foster.service.IAreaService;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 区域
 *
 * @author flyer
 * @since 2024-05-09
 */
@RestController
@RequestMapping("/admin/area")
public class AreaController {
    @Autowired
    private IAreaService iAreaService;

    /**
     * 区域列表-分页
     *
     * @param current 当前页
     * @param size    当前页显示条数
     * @return
     */
    @GetMapping("/list/{current}/{size}")
    public R getPageList(@PathVariable Integer current, @PathVariable Integer size, AreaQueryDTO queryDTO) {
        IPage<AreaRespDTO> page = new Page<>(current, size);
        return R.ok().result(iAreaService.getPageList(page, queryDTO));
    }

    /**
     * 根据区域id获取区域详情
     *
     * @param areaId
     * @return
     */
    @GetMapping("/{areaId}")
    public R getById(@PathVariable Integer areaId) {
        return R.ok().result(iAreaService.getById(areaId));
    }

    /**
     * 区域列表
     *
     * @param areaQueryDTO 查询对象
     * @return
     */
    @GetMapping("/list")
    public R getByGardenId(@Valid AreaQueryDTO areaQueryDTO) {
        return R.ok().result(iAreaService.lambdaQuery().eq(Area::getGardenId, areaQueryDTO.getGardenId()).list());
    }

    /**
     * 新增区域
     *
     * @param addDTOList
     * @return
     */
    @PostMapping("")
    public R addArea(@Valid @RequestBody List<AreaAddDTO> addDTOList) {
        return R.ok().result(iAreaService.addArea(addDTOList));
    }

    /**
     * 修改区域
     *
     * @param areaId
     * @param updateDTO
     * @return
     */
    @PutMapping("/{areaId}")
    public R updateArea(@PathVariable Integer areaId, @RequestBody AreaUpdateDTO updateDTO) {
        updateDTO.setId(areaId);
        return R.ok().result(iAreaService.updateArea(updateDTO));
    }

    /**
     * 删除区域
     *
     * @return
     */
    @PostMapping("/delete")
    public R deleteArea(@RequestBody List<Integer> idList) {
        return R.ok().result(iAreaService.deleteByIdList(idList));
    }
}
